==> knowledge-center-api-0.1.2-sources.jar: cn/yoofans/knowledge/center/api/dto/read/ReadBookCourseDTO.java <==
/**
 * Copyright (C), 2015-2018, XXX有限公司
 * FileName: ReadBookCourseDTO
 * Author:   amu
 * Date:     2018/5/23 上午10:08
 * Description:
 * History:
 * <author>          <time>          <version>          <desc>
 * 作者姓名           修改时间           版本号              描述
 */
package cn.yoofans.knowledge.center.api.dto.read;

import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * 〈一句话功能简述〉<br>
 *
 * @author amu
 * @create 2018/5/23
 * @since 1.0.0
 */
public class ReadBookCourseDTO implements Serializable {

    private static final long serialVersionUID = -2556567083163693655L;

    private Long id;

    private Long bookId;

    private Long courseId;

    private Long readId;

    private Integer dayNum;

    private String imgUrl;

    private String title;

    private String subTitle;

    private Integer courseType;

    private String lateralCover;

    private String verticalCover;

    private Long newCourseId;

    private String shareDocument;

    private String content1;

    private String content2;

    private String content3;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getBookId() {
        return bookId;
    }

    public void setBookId(Long bookId) {
        this.bookId = bookId;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public Long getReadId() {
        return readId;
    }

    public void setReadId(Long readId) {
        this.readId = readId;
    }

    public Integer getDayNum() {
        return dayNum;
    }

    public void setDayNum(Integer dayNum) {
        this.dayNum = dayNum;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }

    public Integer getCourseType() {
        return courseType;
    }

    public void setCourseType(Integer courseType) {
        this.courseType = courseType;
    }

    public String getLateralCover() {
        return lateralCover;
    }

    public void setLateralCover(String lateralCover) {
        this.lateralCover = lateralCover;
    }

    public String getVerticalCover() {
        return verticalCover;
    }

    public void setVerticalCover(String verticalCover) {
        this.verticalCover = verticalCover;
    }

    public Long getNewCourseId() {
        return newCourseId;
    }

    public void setNewCourseId(Long newCourseId) {
        this.newCourseId = newCourseId;
    }

    public String getShareDocument() {
        return shareDocument;
    }

    public void setShareDocument(String shareDocument) {
        this.shareDocument = shareDocument;
    }

    public String getContent1() {
        return content1;
    }

    public void setContent1(String content1) {
        this.content1 = content1;
    }

    public String getContent2() {
        return content2;
    }

    public void setContent2(String content2) {
        this.content2 = content2;
    }

    public String getContent3() {
        return content3;
    }

    public void setContent3(String content3) {
        this.content3 = content3;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> knowledge-center-api-0.1.10-sources.jar: cn/yoofans/knowledge/center/api/dto/read/ReadBookCourseDTO.java <==
/**
 * Copyright (C), 2015-2018, XXX有限公司
 * FileName: ReadBookCourseDTO
 * Author:   amu
 * Date:     2018/5/23 上午10:08
 * Description:
 * History:
 * <author>          <time>          <version>          <desc>
 * 作者姓名           修改时间           版本号              描述
 */
package cn.yoofans.knowledge.center.api.dto.read;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * 〈一句话功能简述〉<br>
 *
 * @author amu
 * @create 2018/5/23
 * @since 1.0.0
 */
public class ReadBookCourseDTO implements Serializable {

    private static final long serialVersionUID = -2556567083163693655L;

    private Long id;

    private Long bookId;

    private Long courseId;

    private Long readId;

    private Integer dayNum;

    private String imgUrl;

    private String title;

    private String subTitle;

    private Integer courseType;

    private String lateralCover;

    private String verticalCover;

    private Long newCourseId;

    private String shareDocument;

    private String content1;

    private String content2;

    private String content3;

    /**
     * H5观点分享自定义图片
     */
    private String shareUrl;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getBookId() {
        return bookId;
    }

    public void setBookId(Long bookId) {
        this.bookId = bookId;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public Long getReadId() {
        return readId;
    }

    public void setReadId(Long readId) {
        this.readId = readId;
    }

    public Integer getDayNum() {
        return dayNum;
    }

    public void setDayNum(Integer dayNum) {
        this.dayNum = dayNum;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }

    public Integer getCourseType() {
        return courseType;
    }

    public void setCourseType(Integer courseType) {
        this.courseType = courseType;
    }

    public String getLateralCover() {
        return lateralCover;
    }

    public void setLateralCover(String lateralCover) {
        this.lateralCover = lateralCover;
    }

    public String getVerticalCover() {
        return verticalCover;
    }

    public void setVerticalCover(String verticalCover) {
        this.verticalCover = verticalCover;
    }

    public Long getNewCourseId() {
        return newCourseId;
    }

    public void setNewCourseId(Long newCourseId) {
        this.newCourseId = newCourseId;
    }

    public String getShareDocument() {
        return shareDocument;
    }

    public void setShareDocument(String shareDocument) {
        this.shareDocument = shareDocument;
    }

    public String getContent1() {
        return content1;
    }

    public void setContent1(String content1) {
        this.content1 = content1;
    }

    public String getContent2() {
        return content2;
    }

    public void setContent2(String content2) {
        this.content2 = content2;
    }

    public String getContent3() {
        return content3;
    }

    public void setContent3(String content3) {
        this.content3 = content3;
    }

    public String getShareUrl() {
        return shareUrl;
    }

    public void setShareUrl(String shareUrl) {
        this.shareUrl = shareUrl;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
